@@ -1,7 +1,7 @@
 ### This is a python package used for configuring a Morpheus appliance ###
 
 from .appliance import (
-   morphAppliance
+   morpheusAppliance
 )
 
 # from .configs import (
