@@ -3,7 +3,7 @@ import requests
 import urllib3
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
-class morphAppliance(object):
+class morpheusAppliance(object):
     def __init__(self, app_name, app_hostname, account_name, user_name, password, email, first_name, access_token, license_key):
         self.app_name = app_name
         self.app_hostname = app_hostname
